==> tmdbv3api-1.6.2-py2.py3-none-any.whl: tmdbv3api/objs/movie.py <==
from tmdbv3api.tmdb import TMDb
from tmdbv3api.as_obj import AsObj

try:
    from urllib import quote
except ImportError:
    from urllib.parse import quote


class Movie(TMDb):
    _urls = {
        "details": "/movie/%s",
        "reviews": "/movie/%s/reviews",
        "lists": "/movie/%s/lists",
        "videos": "/movie/%s/videos",
        "recommendations": "/movie/%s/recommendations",
        "latest": "/movie/latest",
        "now_playing": "/movie/now_playing",
        "top_rated": "/movie/top_rated",
        "upcoming": "/movie/upcoming",
        "popular": "/movie/popular",
        "search_movie": "/search/movie",
        "similar": "/movie/%s/similar",
        "credits": "/movie/%s/credits",
        "images": "/movie/%s/images",
        "keywords": "/movie/%s/keywords",
        "external": "/find/%s",
        "external_ids": "/movie/%s/external_ids",
    }

    def keywords(self, movie_id):
        """
        Get the keywords associated to a movie.
        :param movie_id:
        :return:
        """
        return self._get_obj(
            self._call(self._urls["keywords"] % movie_id, ""), "keywords"
        )

    def details(
        self,
        movie_id,
        append_to_response="videos,trailers,images,casts,translations,keywords",
    ):
        """
        Get the primary information about a movie.
        :param movie_id:
        :param append_to_response:
        :return:
        """
        return AsObj(
            **self._call(
                self._urls["details"] % movie_id,
                "append_to_response=" + append_to_response,
            )
        )

    def credits(self, movie_id):
        """
        Get the cast and crew for a movie.
        :param movie_id:
        :return:
        """
        return AsObj(**self._call(self._urls["credits"] % movie_id, ""))

    def reviews(self, movie_id, page=1):
        """
        Get the user reviews for a movie.
        :param movie_id:
        :param page:
        :return:
        """
        return self._get_obj(
            self._call(self._urls["reviews"] % movie_id, "page=" + str(page))
        )

    def lists(self, movie_id, page=1):
        """
        Get a list of lists that this movie belongs to.
        :param movie_id:
        :param page:
        :return:
        """
        return self._get_obj(
            self._call(self._urls["lists"] % movie_id, "page=" + str(page))
        )

    def videos(self, id, page=1):
        """
        Get the videos that have been added to a movie.
        :param id:
        :param page:
        :return:
        """
        return self._get_obj(self._call(self._urls["videos"] % id, "page=" + str(page)))

    def recommendations(self, movie_id, page=1):
        """
        Get a list of recommended movies for a movie.
        :param movie_id:
        :param page:
        :return:
        """
        return self._get_obj(
            self._call(self._urls["recommendations"] % movie_id, "page=" + str(page))
        )

    def latest(self):
        """
        Get the most newly created movie. This is a live response and will continuously change.
        :return:
        """
        return AsObj(**self._call(self._urls["latest"], ""))

    def now_playing(self, page=1):
        """
        Get a list of movies in theatres.
        :param page:
        :return:
        """
        return self._get_obj(self._call(self._urls["now_playing"], "page=" + str(page)))

    def top_rated(self, page=1):
        """
        Get the top rated movies on TMDb.
        :param page:
        :return:
        """
        return self._get_obj(self._call(self._urls["top_rated"], "page=" + str(page)))

    def upcoming(self, page=1):
        """
        Get a list of upcoming movies in theatres.
        :param page:
        :return:
        """
        return self._get_obj(self._call(self._urls["upcoming"], "page=" + str(page)))

    def popular(self, page=1):
        """
        Get a list of the current popular movies on TMDb. This list updates daily.
        :param page:
        :return:
        """
        return self._get_obj(self._call(self._urls["popular"], "page=" + str(page)))

    def search(self, term, page=1):
        """
        Search for movies.
        :param term:
        :param page:
        :return:
        """
        return self._get_obj(
            self._call(
                self._urls["search_movie"],
                "query=" + quote(term) + "&page=" + str(page),
            )
        )

    def similar(self, movie_id, page=1):
        """
        Get a list of similar movies.
        :param movie_id:
        :param page:
        :return:
        """
        return self._get_obj(
            self._call(self._urls["similar"] % movie_id, "page=" + str(page))
        )

    def external(self, external_id, external_source):
        """
        The find method makes it easy to search for objects in our database by an external id. For example, an IMDB ID.
        :param external_id: str
        :param external_source str
        :return:
        """
        return self._get_obj(
            self._call(
                self._urls["external"] % external_id,
                "external_source=" + external_source,
            ),
            key=None,
        )

    def images(self, movie_id):
        """
        Get the images that belong to a movie.
        :param movie_id:
        :return:
        """
        return AsObj(**self._call(self._urls["images"] % movie_id, ""))

    def external_ids(self, movie_id):
        """
        Get the external ids for a movie.
        :param movie_id:
        :return:
        """
        return self._get_obj(
            self._call(self._urls["external_ids"] % (str(movie_id)), ""), None
        )

==> tmdbv3api-1.7.6-py2.py3-none-any.whl: tmdbv3api/objs/movie.py <==
from tmdbv3api.tmdb import TMDb
from tmdbv3api.as_obj import AsObj

try:
    from urllib import quote
except ImportError:
    from urllib.parse import quote

try:
    from urllib import urlencode
except ImportError:
    from urllib.parse import urlencode

class Movie(TMDb):
    _urls = {
        "details": "/movie/%s",
        "alternative_titles": "/movie/%s/alternative_titles",
        "changes": "/movie/%s/changes",
        "credits": "/movie/%s/credits",
        "external_ids": "/movie/%s/external_ids",
        "images": "/movie/%s/images",
        "keywords": "/movie/%s/keywords",
        "lists": "/movie/%s/lists",
        "reviews": "/movie/%s/reviews",
        "videos": "/movie/%s/videos",
        "recommendations": "/movie/%s/recommendations",
        "latest": "/movie/latest",
        "now_playing": "/movie/now_playing",
        "top_rated": "/movie/top_rated",
        "upcoming": "/movie/upcoming",
        "popular": "/movie/popular",
        "search_movie": "/search/movie",
        "similar": "/movie/%s/similar",
        "external": "/find/%s",
        "release_dates": "/movie/%s/release_dates",
    }

    def details(
        self,
        movie_id,
        append_to_response="videos,trailers,images,casts,translations,keywords,release_dates",
    ):
        """
        Get the primary information about a movie.
        :param movie_id:
        :param append_to_response:
        :return:
        """
        return AsObj(
            **self._call(
                self._urls["details"] % movie_id,
                "append_to_response=" + append_to_response,
            )
        )

    def alternative_titles(self, movie_id, country=""):
        """
        Get all of the alternative titles for a movie.
        :param movie_id:
        :param country:
        :return:
        """
        return AsObj(**self._call(self._urls["alternative_titles"] % movie_id, "country=" + country))

    def changes(self, movie_id, start_date="", end_date="", page=1):
        """
        Get all of the alternative titles for a movie.
        You can query up to 14 days in a single query by using the start_date and end_date query parameters.
        :param movie_id:
        :param start_date:
        :param end_date:
        :param page:
        :return:
        """
        return self._get_obj(
            self._call(
                self._urls["changes"] % movie_id,
                urlencode({
                    "start_date": str(start_date),
                    "end_date": str(end_date),
                    "page": str(page)
                })
            ),
            "changes"
        )

    def credits(self, movie_id):
        """
        Get the cast and crew for a movie.
        :param movie_id:
        :return:
        """
        return AsObj(**self._call(self._urls["credits"] % movie_id, ""))

    def external_ids(self, movie_id):
        """
        Get the external ids for a movie.
        :param movie_id:
        :return:
        """
        return self._get_obj(
            self._call(self._urls["external_ids"] % (str(movie_id)), ""), None
        )
    
    def images(self, movie_id, include_image_language=""):
        """
        Get the images that belong to a movie.
        Querying images with a language parameter will filter the results. 
        If you want to include a fallback language (especially useful for backdrops) you can use the include_image_language parameter. 
        This should be a comma seperated value like so: include_image_language=en,null.
        :param movie_id:
        :param include_image_language:
        :return:
        """
        return AsObj(**self._call(self._urls['images'] % movie_id, "include_image_language=" + include_image_language))

    def keywords(self, movie_id):
        """
        Get the keywords associated to a movie.
        :param movie_id:
        :return:
        """
        return AsObj(**self._call(self._urls['keywords'] % movie_id, ''))

    def lists(self, movie_id, page=1):
        """
        Get a list of lists that this movie belongs to.
        :param movie_id:
        :param page:
        :return:
        """
        return self._get_obj(
            self._call(self._urls["lists"] % movie_id, "page=" + str(page))
        )

    def recommendations(self, movie_id, page=1):
        """
        Get a list of recommended movies for a movie.
        :param movie_id:
        :param page:
        :return:
        """
        return self._get_obj(
            self._call(self._urls["recommendations"] % movie_id, "page=" + str(page))
        )

    def release_dates(self, movie_id):
        """
        Get the release date along with the certification for a movie.
        :param movie_id:
        :return:
        """
        return AsObj(**self._call(self._urls['release_dates'] % movie_id, ''))

    def reviews(self, movie_id, page=1):
        """
        Get the user reviews for a movie.
        :param movie_id:
        :param page:
        :return:
        """
        return self._get_obj(
            self._call(self._urls["reviews"] % movie_id, "page=" + str(page))
        )

    def videos(self, id, page=1):
        """
        Get the videos that have been added to a movie.
        :param id:
        :param page:
        :return:
        """
        return self._get_obj(self._call(self._urls["videos"] % id, "page=" + str(page)))

    def latest(self):
        """
        Get the most newly created movie. This is a live response and will continuously change.
        :return:
        """
        return AsObj(**self._call(self._urls["latest"], ""))

    def now_playing(self, page=1):
        """
        Get a list of movies in theatres.
        :param page:
        :return:
        """
        return self._get_obj(self._call(self._urls["now_playing"], "page=" + str(page)))

    def top_rated(self, page=1):
        """
        Get the top rated movies on TMDb.
        :param page:
        :return:
        """
        return self._get_obj(self._call(self._urls["top_rated"], "page=" + str(page)))

    def upcoming(self, page=1):
        """
        Get a list of upcoming movies in theatres.
        :param page:
        :return:
        """
        return self._get_obj(self._call(self._urls["upcoming"], "page=" + str(page)))

    def popular(self, page=1):
        """
        Get a list of the current popular movies on TMDb. This list updates daily.
        :param page:
        :return:
        """
        return self._get_obj(self._call(self._urls["popular"], "page=" + str(page)))

    def search(self, term, page=1):
        """
        Search for movies.
        :param term:
        :param page:
        :return:
        """
        return self._get_obj(
            self._call(
                self._urls["search_movie"],
                "query=" + quote(term) + "&page=" + str(page),
            )
        )

    def similar(self, movie_id, page=1):
        """
        Get a list of similar movies.
        :param movie_id:
        :param page:
        :return:
        """
        return self._get_obj(
            self._call(self._urls["similar"] % movie_id, "page=" + str(page))
        )

    def external(self, external_id, external_source):
        """
        The find method makes it easy to search for objects in our database by an external id. For example, an IMDB ID.
        :param external_id: str
        :param external_source str
        :return:
        """
        return self._get_obj(
            self._call(
                self._urls["external"] % external_id,
                "external_source=" + external_source,
            ),
            key=None,
        )
